package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````F",```````!``````````(BA````
M`````````$``.``(`$``&@`9``8````%````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````%24````````5)0`````````
M``$```````$````&````Z)H```````#HF@$``````.B:`0``````F`4`````
M``#(%0```````````0```````@````8`````FP````````";`0```````)L!
M``````!0`@```````%`"````````"``````````$````!````!P"````````
M'`(````````<`@```````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```#HF@```````.B:`0``````Z)H!```````8!0``````
M`!@%`````````0`````````O;&EB+VQD+6QI;G5X+6%A<F-H-C0N<V\N,0``
M!````!`````!````1TY5```````#````!P`````````$````%`````,```!'
M3E4`E.)0O"QZT3H[@S&OIX[`1*5Z`*$1````40````0````(````(1`0``7`
M!(0H`A`!@(9`@((I``0)(`2)B*`81;H$`@A1````4@```%8```!;````7```
M`&,```!D````90```&<```!H`````````&H```!K````;````&X`````````
M``````&O-.ANQ=\?ZM/O#L[>1RUK?YI\+L6;MG94/)0@_^0.N(WQ#M5DU'S9
M<5@<XD?&`:Q+X\"ZXY)\6.^7><+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'
M<-,-%.*>VLWCGC-BV^T-.I<+?ZF<F[[:5QOAIP(*H^#[20``````````````
M`````````````````````````````P`+`!`=````````````````````````
M`P`3`/B:`0````````````````#H`@``$@````````````````````````!L
M`P``$@````````````````````````"X`@``$@``````````````````````
M``"_`@``$@````````````````````````!>`P``$@``````````````````
M``````!?`@``$@`````````````````````````1````(```````````````
M```````````0`P``$@`````````````````````````H`P``$@``````````
M``````````````!/`P``(@`````````````````````````A`P``$@``````
M```````````````````(`P``$@````````````````````````#(````$@``
M```````````````````````:`P``$0````````````````````````"7`0``
M$@````````````````````````!-`@``$@````````````````````````!L
M`@``$@````````````````````````"8````$@``````````````````````
M```@`0``$@`````````````````````````Q`P``$@``````````````````
M``````"Q`@``$@````````````````````````"^`0``$@``````````````
M```````````5`0``$0````````````````````````#O`@``$@``````````
M``````````````![`0``$@````````````````````````#W````$0``````
M``````````````````!)`0``$@````````````````````````!D`@``$@``
M``````````````````````""`P``$@````````````````````````#&`@``
M$@````````````````````````#6````$@````````````````````````#%
M`0``$@`````````````````````````V`@``$@``````````````````````
M``"R`0``$@`````````````````````````$`@``$@``````````````````
M``````"<`@``$@````````````````````````!U`@``$@``````````````
M``````````!^`@``$@`````````````````````````8`@``$@``````````
M``````````````!7`0``$@`````````````````````````M````(```````
M``````````````````"T`P``$0````````````````````````"5`P``(0``
M``````````````````````"D`@``$@````````````````````````!T`P``
M$@````````````````````````#0`0``$0````````````````````````!X
M````$@````````````````````````#:`@``$@``````````````````````
M``![`P``$@````````````````````````!!!```$@``````````````````
M``````#4`@``$@````````````````````````"G````$@``````````````
M``````````"S````$@````````````````````````!P`0``$@``````````
M``````````````#]`@``$@`````````````````````````V`0``$@``````
M```````````````````E`0``$@````````````````````````!J````$@``
M``````````````````````!%`P``$@`````````````````````````J`0``
M$@````````````````````````"G`0``$@`````````````````````````$
M`0``$@`````````````````````````^`P``$@``````````````````````
M``")`0``$@````````````````````````"'````$@``````````````````
M```````^`@``$@````````````````````````"J`@``$@``````````````
M``````````"4`P``$0````````````````````````"6`P``$0``````````
M```````````````\````(``````````````````````````>`@``$@``````
M``````````````````#H````$@````````````````````````!G`0``$@``
M``````````````````````#-`@``$@````````````````````````!0````
M(``````````````````````````E`@``$@````````````````````````"/
M`@``$@````````````````````````"6`@``$@``````````````````````
M``#V`P``$``7`+"P`0````````````````!*!```$@`-`-!2````````B```
M```````8!```$@`.`/13``````````````````!O!```$@`-`)!%````````
MG`D```````"/`P``$@`-`%`A````````2`(````````>!```$@`-`(@^````
M````!`````````#G`P``$``7`("@`0````````````````#=!```$@`-`)`^
M````````)`(```````#7!```$@`+`!`=```````````````````*!0``$@`-
M`#!/````````G`,```````#;`P``$``7`("@`0````````````````!6!```
M$@`-`+A`````````(`````````")!```$0`/``A4````````!``````````)
M!```$``7`+"P`0`````````````````!!```$``7`+"P`0``````````````
M``#5!```$@`-`!`]````````.`````````#J!```$@`-`)A$````````]```
M``````#\!```$@`-`-A#````````F`````````!\!```$``6``"@`0``````
M``````````!C!```$@`-`-A`````````.`$```````#4`P``$``6`("@`0``
M``````````````"^!```$0`6`'B@`0``````"``````````.!```$@`-`/!3
M````````!`````````"N!```$@`-`'A3````````>`````````""!```$@`-
M`)@C``````````````````!^!```(``6``"@`0`````````````````O!```
M$@`-`'!$````````*`````````#U`P``$``7`+"P`0````````````````"8
M!```$@`-`*`]````````Y`````````#(!```$@`-`!!"````````R`$`````
M````;&EB<&5R;"YS;RXU+C(V`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G
M:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET
M,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V
M`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R
M<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W
M6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E
M=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`;&EB
M;2YS;RXV`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E='-P96-I9FEC`&-L
M;W-E`&]P96XV-`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`<F5A9`!L:6)C
M+G-O+C8`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P
M`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL
M;V,`86)O<G0`;65M8VAR`&=E='!I9`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S
M=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H
M:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`
M<F5A9&QI;FL`7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?
M9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``
M7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`&QD+6QI;G5X+6%A<F-H-C0N
M<V\N,0!?7W-T86-K7V-H:U]G=6%R9`!L:6)C<GEP="YS;RXQ`%]E9&%T80!?
M7V)S<U]S=&%R=`!?7V)S<U]S=&%R=%]?`%]?8G-S7V5N9%]?`%]?96YD7U\`
M7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!P87)?8F%S96YA;64`
M<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!?24]?<W1D
M:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET
M`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`
M<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?
M4$%27T)/3U0`1TQ)0D-?,BXQ-P```````````@`"``(``@`"``(````"``(`
M`@`"``(````"`````@`"```````"``(``@````(``````````@`"``(`````
M``,````#``(``@`"``,```````0``@`"``(```````(``@`"``(`````````
M`@````(````"``````````(```````,``@`"``(````#```````"`````P`"
M``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``````````0`!`)X#```0````(````)>1E@8`
M``0`(`4````````!``$`]`$``!`````@````EY&6!@```P`@!0````````$`
M`0!#`@``$`````````"7D98&```"`"`%````````Z)H!```````#!```````
M`*@D````````\)H!```````#!````````&`D````````<)\!```````#!```
M`````/!3````````N)\!```````#!`````````B@`0``````R)\!```````#
M!````````'A3````````V)\!```````#!````````%`A````````"*`!````
M```#!`````````B@`0``````&*`!```````#!````````!!8````````(*`!
M```````#!````````+!4````````,*`!```````#!````````*!5````````
M.*`!```````#!````````/!7````````0*`!```````#!````````/A7````
M````2*`!```````#!`````````!8````````4*`!```````#!`````````A8
M````````8*`!```````#!````````-A7````````:*`!```````#!```````
M`.!7````````>*`!```````#!````````!A8````````>)\!```````!!```
M"0``````````````@)\!```````!!```#```````````````B)\!```````!
M!```$```````````````D)\!```````!!```$0``````````````F)\!````
M```!!```&0``````````````H)\!```````!!```'```````````````J)\!
M```````!!```*P``````````````L)\!```````!!```+```````````````
MP)\!```````!!```,```````````````T)\!```````!!```.@``````````
M````X)\!```````!!```0P``````````````Z)\!```````!!```1P``````
M````````\)\!```````!!```2```````````````^)\!```````!!```30``
M````````````:)T!```````"!````P``````````````<)T!```````"!```
M!```````````````>)T!```````"!```!0``````````````@)T!```````"
M!```!@``````````````B)T!```````"!```!P``````````````D)T!````
M```"!```"```````````````F)T!```````"!```"@``````````````H)T!
M```````"!```"P``````````````J)T!```````"!```#```````````````
ML)T!```````"!```#0``````````````N)T!```````"!```#@``````````
M````P)T!```````"!```#P``````````````R)T!```````"!```$@``````
M````````T)T!```````"!```$P``````````````V)T!```````"!```%```
M````````````X)T!```````"!```%0``````````````Z)T!```````"!```
M%@``````````````\)T!```````"!```%P``````````````^)T!```````"
M!```&````````````````)X!```````"!```&@``````````````")X!````
M```"!```&P``````````````$)X!```````"!```'0``````````````&)X!
M```````"!```'@``````````````()X!```````"!```'P``````````````
M*)X!```````"!```(```````````````,)X!```````"!```(0``````````
M````.)X!```````"!```(@``````````````0)X!```````"!```(P``````
M````````2)X!```````"!```)```````````````4)X!```````"!```)0``
M````````````6)X!```````"!```)@``````````````8)X!```````"!```
M)P``````````````:)X!```````"!```*```````````````<)X!```````"
M!```*0``````````````>)X!```````"!```*@``````````````@)X!````
M```"!```*P``````````````B)X!```````"!```+@``````````````D)X!
M```````"!```+P``````````````F)X!```````"!```,0``````````````
MH)X!```````"!```,@``````````````J)X!```````"!```,P``````````
M````L)X!```````"!```-```````````````N)X!```````"!```-0``````
M````````P)X!```````"!```-@``````````````R)X!```````"!```-P``
M````````````T)X!```````"!```.```````````````V)X!```````"!```
M.0``````````````X)X!```````"!```.P``````````````Z)X!```````"
M!```/```````````````\)X!```````"!```/0``````````````^)X!````
M```"!```/@```````````````)\!```````"!```/P``````````````")\!
M```````"!```0```````````````$)\!```````"!```00``````````````
M&)\!```````"!```0@``````````````()\!```````"!```1```````````
M````*)\!```````"!```10``````````````,)\!```````"!```20``````
M````````.)\!```````"!```2@``````````````0)\!```````"!```2P``
M````````````2)\!```````"!```3```````````````4)\!```````"!```
M3@``````````````6)\!```````"!```3P``````````````8)\!```````"
M!```4```````````````_7N_J?T#`)&N`0"4_7O!J,`#7]8`````````````
M``#P>[^IT```D!&R1OD0@C61(`(?UA\@`]4?(`/5'R`#U=```)`1MD;Y$*(U
MD2`"'];0``"0$;I&^1#"-9$@`A_6T```D!&^1OD0XC61(`(?UM```)`1PD;Y
M$`(VD2`"'];0``"0$<9&^1`B-I$@`A_6T```D!'*1OD00C:1(`(?UM```)`1
MSD;Y$&(VD2`"'];0``"0$=)&^1""-I$@`A_6T```D!'61OD0HC:1(`(?UM``
M`)`1VD;Y$,(VD2`"'];0``"0$=Y&^1#B-I$@`A_6T```D!'B1OD0`C>1(`(?
MUM```)`1YD;Y$"(WD2`"'];0``"0$>I&^1!"-Y$@`A_6T```D!'N1OD08C>1
M(`(?UM```)`1\D;Y$((WD2`"'];0``"0$?9&^1"B-Y$@`A_6T```D!'Z1OD0
MPC>1(`(?UM```)`1_D;Y$.(WD2`"'];0``"0$0)'^1`".)$@`A_6T```D!$&
M1_D0(CB1(`(?UM```)`1"D?Y$$(XD2`"'];0``"0$0Y'^1!B.)$@`A_6T```
MD!$21_D0@CB1(`(?UM```)`1%D?Y$*(XD2`"'];0``"0$1I'^1#".)$@`A_6
MT```D!$>1_D0XCB1(`(?UM```)`1(D?Y$`(YD2`"'];0``"0$29'^1`B.9$@
M`A_6T```D!$J1_D00CF1(`(?UM```)`1+D?Y$&(YD2`"'];0``"0$3)'^1""
M.9$@`A_6T```D!$V1_D0HCF1(`(?UM```)`1.D?Y$,(YD2`"'];0``"0$3Y'
M^1#B.9$@`A_6T```D!%"1_D0`CJ1(`(?UM```)`11D?Y$"(ZD2`"'];0``"0
M$4I'^1!".I$@`A_6T```D!%.1_D08CJ1(`(?UM```)`14D?Y$((ZD2`"'];0
M``"0$59'^1"B.I$@`A_6T```D!%:1_D0PCJ1(`(?UM```)`17D?Y$.(ZD2`"
M']:P``#P$6)'^1`".Y$@`A_6L```\!%F1_D0(CN1(`(?UK```/`1:D?Y$$([
MD2`"']:P``#P$6Y'^1!B.Y$@`A_6L```\!%R1_D0@CN1(`(?UK```/`1=D?Y
M$*([D2`"']:P``#P$7I'^1#".Y$@`A_6L```\!%^1_D0XCN1(`(?UK```/`1
M@D?Y$`(\D2`"']:P``#P$89'^1`B/)$@`A_6L```\!&*1_D00CR1(`(?UK``
M`/`1CD?Y$&(\D2`"']:P``#P$9)'^1""/)$@`A_6L```\!&61_D0HCR1(`(?
MUK```/`1FD?Y$,(\D2`"']:P``#P$9Y'^1#B/)$@`A_6L```\!&B1_D0`CV1
M(`(?UK```/`1ID?Y$"(]D2`"']:P``#P$:I'^1!"/9$@`A_6L```\!&N1_D0
M8CV1(`(?UK```/`1LD?Y$((]D2`"'];]>[FI_0,`D?-3`:FT``#P]5L"J;,`
M`/#W&P#Y@]I'^:*'!*FA0P&1H%\`N:(C`9&@<P&19`!`^:0W`/D$`(#2B/__
MEZ(``/"@``#P0NA'^0#P1_GA`P*J;`P`E*```/``T$?Y``!`.6`!`#5-__^7
MP@``L$!4`/D@#@"TLP``\!C__Y=@SD?Y``!`N5'__Y<?A"0Y<\Y'^6`"0+E-
M__^7`>A3.2$`'S(!Z!,Y8`)`N4C__Y<"Z%,YH5]`N0,`_))"```R(10`$0+H
M$SDA?$"3/P`#ZV@)`%0@\'W3TP``L#C__Y>D*T#YQ@``D&4B!I&B7T"Y`P``
M\`$``/#'/$#YB`"`4H8`0/EC(!^1(4`?D5\$`'$&#`"I!P0!J:B`$+B@`!'X
MC0<`5(0@`)%#$``1H0"`4N<`@)+ES"&+AH1`^"$$`!$_``-K!F@E^&'__U1V
M(@:1!<PCBP$``+#C`P"J0@P`$2$@-9'``E+X!`"`TK^`'_AO__^7]0,`*B`#
M`#1V(@:1MY,!D<`"4OCM_O^7````\.$#%ZH`P!21U00`E(`"`+1S(@:18`)2
M^-'^_Y=4__^7E-I'^>`#%2JB-T#Y@0)`^4$``<KA`P"U\U-!J?5;0JGW&T#Y
M_7O'J,`#7];``E+X<___E_4#`"KE__\7P()1^$`!`+3B"P"4ZO__%Z$``/``
M``#P```?D2'@1_DL__^70P`("\[__Q<```#PX0,7J@#@$I&R!`"4P((1^*#[
M_[33"P"4V___%R``@%*$_O^7[_[_EQT`@-(>`(#2Y0,`JN$#0/GB(P"1Y@,`
MD:```/``[$?YHP``\&/D1_FD``#PA+A'^;[^_Y?Q_O^7H```\`#41_E```"T
MZ?[_%\`#7]8`````P0``D,```)`A``*1```"D2$<`)$A``#+/S@`\:D``%2A
M``#P(;Q'^4$``+0@`!_6P`-?UA\@`]7!``"0P```D"$``I$```*1(0``RR'\
M0Y,A_$&+(?Q!D\$``+2B``#P0OQ'^6(``+1``!_6'R`#U<`#7]8?(`/5_7N^
MJ?T#`)'S"P#YTP``D&`"0CE``0`UH```\`#`1_F```"TP```D``$0/E1_O^7
MUO__ER``@%)@`@(Y\PM`^?U[PJC``U_6H```\`#@*Y$!`$#Y80``M=K__Q<?
M(`/5H0``\"'X1_F!__^T_7N_J?T#`)$@`#_6_7O!J-'__Q?_0PK1J```\`3@
M`)$)X`&1_7N_J?T#`)$!V4?YHF,`D4<@`)$C`$#YHT\!^0,`@-*!`$"Y@X1`
M^"$(P%KA@!_XGP`)ZV'\8--E_&C3)MQXTZ4<>)(A'&C3QAQPDB$`!JJCX$.J
M(0`#JN$$`?@A_O]41@`(D40`0/E"(`"10P1`^44<0/E!,$#Y8P`$RM\``NLA
M``7*(0`#RB/\7]-A!`&J(7Q`DD$\`/EA_O]4!R1`J2$SC](*+$&I(`%GGD(!
M9YZB#T#Y80%GGD%0J_)#``&+XOQ;TPP00/E"%`>JL!M`^1`"`8M`'&$N!`!F
MGN``9YZ"0"*+)/U"TT(``XNC$T#YA'@)JD(`#(N.?$"290`!B\$!9YY&?$"2
MQ/Q;TX04!JH@'&(N`P!FGF,`"XMC``6+9$`DB^/\0M.-?$"28W@'JF]\0)*C
M%T#Y0@`/BF4``8O#`2:*8P`"JL+\0M-C``J+8P`%BZ7]6]-">`:JY@$MBJ44
M#:I"?$"2A``"BF-`)8O$``2J97Q`DH0`#HN$`!"+IOQ;T\84!:J$0":+IOU"
MT\UX#:J&?$"2K7U`DFX`#8JC'T#Y<``!BT,`)8IC``ZJSOQ;TV,`#XO.%0:J
M8P`0B[`C0/EC0"Z+KOQ"TQ`"`8O%>06JK@$FBJ5\0)*/``6*9'Q`DLX!#ZK"
M`0*+COQ;TT(`$(O.%02J0D`NB\[\0M-0?$"2QGD&JL9\0))N``:*HR=`^6\`
M`8NC`"2*8P`.JF,`#8L-_EO38P`/BZT5$*IC0"V+C?Q"TV]\0)*D>02JA'Q`
MDDT`!(JB*T#Y3@`!B\(`,(I"``VJ[?U;TT(`!8L%_D+3K14/JD(`#HNE>!"J
MI7Q`DD)`+8MM``6*HR]`^4Y\0))P``&+@P`OBF,`#:IC``:+S?U;T^;]0M-C
M`!"+K14.JL9X#ZK&?$"28T`MBTT`!HJB,T#Y;WQ`DE```8NB`"Z*0@`-JD(`
M!(OM_5O3Q/U"TT(`$(NM%0^JA'@.JH1\0))"0"V+;0`$BJ,W0/E.?$"2<``!
MB\,`+XIC``VJ8P`%B\W]6]/E_4+38P`0BZT5#JJE>`^JI7Q`DF-`+8M-``6*
MHCM`^6]\0))0``&+@@`NBD(`#:I"``:+[?U;T\;]0M-"`!"+K14/JL9X#JK&
M?$"20D`MBVT`!HJC/T#Y3GQ`DG```8NC`"^*8P`-JF,`!(O-_5O3Y/U"TV,`
M$(NM%0ZJA'@/JH1\0))C0"V+30`$BJ)#0/EO?$"24``!B\(`+HI"``VJ0@`%
MB^W]6]/%_4+30@`0BZT5#ZJE>`ZJI7Q`DD)`+8MM``6*HT=`^4Y\0))P``&+
M@P`OBF,`#:IC``:+QOU;TV,`$(O&%`ZJ8T`FB^;]0M-M?$"2SW@/JN]]0))0
M``^*HDM`^48``8NB`"Z*0@`0JD(`!(ND_5O30@`&B\;]0M.$%`VJQG@.JLY\
M0))"0"2+9@`.BJ-/0/E$?$"2<``!B^,!+8IC``:J8P`%BX7\6]-C`!"+I10$
MJF-`)8NE_4+3K7@-JJ530/FM?4"21@`-BF)\0)*P``&+Q0$DBJ4`!JI&_%O3
MI0`/BZ4`$(O&%`*JI4`FBX;\0M.O?$"2Q'@$JJ970/F$?$"2T``!BV,`!(JF
M`2**Q@`#JN/]6]/&``Z+8Q0/JL8`$(O00".+0_Q"TPY^0))B>`*JHUM`^49\
M0)*E``:*8P`!BX$`+XHA``6JQ?U;TR$`#8LA``.+X_U"TZ44#JIC>`^JS_U"
MTS%`)8M"``/*0@`02C!^0))"``2+(72=TJ1?0/DAVZWR!?Y;T^]Y#JJ$``&+
M0@`$BZ44$*JD8T#Y14`EBP+^0M.N?$"2C0`!BV0`#\I">!"JA``12H0`!HO&
M_5O3A``-B\84#JJ&0":+Y`$"RLU\0)*$``5*A$`CBZ-G0/FE_5O38P`!BX0`
M`XNE%`VJP_U"TX5`)8ND:T#Y;G@.JK!\0))#``[*A``!BV,`!DH&_EO38T`O
MBV,`!(ND_4+3QA00JH1X#:IF0":+PP$$RLU\0))C``5*8T`BBZ)O0/FE_5O3
M0@`!BV,``HNE%`VJ94`EBP/^0M.O?$"28W@0JH(``\I"``9*IG-`^4)`+HO&
M``&+0@`&B^;]6]/&%`^J1D`FBZ+]0M-">`VJS7Q`DFX``LK%`05*I$`DBZ5W
M0/FE``&+A``%BZ7]6].E%`VJA4`EB^3]0M.N?$"2A'@/JD\`!,KF`09*PT`C
MBZ9[0/G&``&+8P`&B\;]6]/&%`ZJ9D`FBZ/]0M-C>`VJS7Q`DH\``\KE`05*
MHD`BBZ5_0/FE``&+0@`%BZ7]6].E%`VJ14`EB\+]0M-">`ZJKGQ`DF\``LKF
M`09*Q$`DBZ:#0/G&``&+A``&B\;]6]/&%`ZJAD`FBZ3]0M.$>`VJS7Q`DD\`
M!,KE`05*HT`CBZ6'0/FE``&+8P`%BZ7]6].E%`VJ94`EB\/]0M.O?$"28W@.
MJHX``\K&`09*PD`BBZ:+0/G&``&+0@`&B^;]6]/&%`^J1D`FBZ+]0M/.?$"2
M0G@-JFT``LJE`05*I$`DBZ6/0/FE``&+A``%B\7]6].E%`ZJA4`EB^3]0M.M
M?$"2A'@/JD\`!,KF`09*PT`CBZ:30/G&``&+8P`&BZ;]6]/&%`VJ9D`FB\/]
M0M-C>`ZJSGQ`DH\``\KE`05*HD`BBZ670/FE``&+0@`%B\7]6].E%`ZJ14`E
MBZ+]0M.P?$"20G@-JFT``LJF`09*#?Y;T\1`)(NFFT#YK140JL8``8N$``:+
MC4`MB\3]0M.O?4"2A'@.JD8`!,K%``5*HT`CBZ6?0/FE``&+8P`%B^7]6].E
M%`^J8T`EBP7^0M-F?$"2L'@0JH4`$,JM``U*I:-`^<[\6].E``&+HD$BBT(`
M!8O.%0:J3D`NB^+]0M/%?4"20G@/J@T"`LJC`0-*K?Q;TV1`)(NCIT#YK14%
MJF,``8N$``.+P_Q"TV9X!JJ$0"V+0P`&RH]\0)*MJT#Y8P`.2J$!`8MC0#"+
M80`!B^/]6].MKT#Y8Q0/JC!`(XNA_$+3`WY`DB5X!:K!``6J(0`$BL0`!8HA
M``0JY/U"TR)`(HN!FY?28>.Q\H1X#ZJM`0&+KP`$BD(`#8MM_%O3K14#JDY`
M+8NM``2JK0$0BL)]0)*M`0\JID$FBZVS0/FM`0&+Q@`-BTW\6].M%0*JST`M
MBV;\0M/#>`.JYGU`DHT``ZJM`0Z*C@`#BJT!#BJE026+K;=`^:T!`8NE``V+
MS?Q;TZT5!JJN0"V+1?Q"TZ)X`JK%?4"2;0`"JJT!#XIO``**K0$/*J1!)(NM
MNT#YK0$!BX0`#8NM_%O3K14%JH]`+8O$_$+3AG@&JN1]0))-``:JK0$.BDX`
M!HJM`0XJHT$CBZV_0/FM`0&+8P`-BXW\6].M%02J;D`MBZ/\0M-E>`6JPWU`
MDLT`!:JM`0^*SP`%BJT!#RJB02*+K<-`^:T!`8M"``V+;?Q;TZT5`ZI/0"V+
M@OQ"TT1X!*KB?4"2K0`$JJT!#HJN``2*K0$.*J9!)HNMQT#YK0$!B\8`#8M-
M_%O3K14"JLY`+8MF_$+3PW@#JL9]0)*-``.JK0$/BH\``XJM`0\JI4$EBZW+
M0/FM`0&+I0`-B\W\6].M%0:JKT`MBT7\0M.B>`*JY7U`DFT``JJM`0Z*;@`"
MBJT!#BJD022+K<]`^:T!`8N$``V+K?Q;TZT5!:J.0"V+Q/Q"TX9X!JK$?4"2
M30`&JJT!#XI/``:*K0$/*J-!(XNMTT#YK0$!BV,`#8N-_%O3K14$JF]`+8NC
M_$+397@%JN-]0)+-``6JK0$.BLX`!8JM`0XJHD$BBZW70/FM`0&+0@`-BVW\
M6].M%0.J3D`MBX+\0M-$>`2JPGU`DJT`!*JM`0^*KP`$BJT!#RJF02:+K=M`
M^:T!`8O&``V+3?Q;TZT5`JK/0"V+9OQ"T\-X`ZKF?4"2C0`#JJT!#HJ.``.*
MK0$.*J5!)8NMWT#YK0$!BZ4`#8O-_%O3K14&JJY`+8M%_$+3HG@"JL5]0))M
M``*JK0$/BF\``HJM`0\JI$$DBZWC0/FM`0&+A``-BZW\6].M%06JCT`MB\3\
M0M.&>`:JY'U`DDT`!JJM`0Z*3@`&BJT!#BJC02.+K>=`^:T!`8MC``V+C?Q;
MTZT5!*IN0"V+H_Q"TV5X!:K#?4"2S0`%JJT!#XK/``6*K0$/*J)!(HNMZT#Y
MK0$!BT(`#8MM_%O3K14#JD]`+8N"_$+31'@$JN)]0)*M``2JK0$.BJX`!(JM
M`0XJID$FBZWO0/FM`0&+Q@`-BTW\6].M%0*JSD`MBV;\0M/-?4"2PW@#JH8`
M`ZK&``^*CP`#BL8`#RK%0"6+IO-`^<8``8NE``:+IOU;T\84#:JP0":+1?Q"
MTP9^0)*B>`*J90`"JJ4`#HIN``**I0`.*J1`)(NE]T#YI0`!BX0`!8O%_%O3
MI10&JH]`)8ND_4+3[GU`DH1X#:I%``2J30`$BJ4`$(JE``TJHT`CBZ7[0/D(
MV4?YH0`!B\7]6]-A``&+P_Q"TZ44#JIC>`:JIO]`^25`)8N!``/*(0`/2JU\
M0)(B0"*+P3J8TD%,N?+&``&+0@`&BZ;]6]/&%`VJ1D`FB\+]0M//?$"23G@.
MJF(`#LI"``5*Y?U;TT)`)(ND`T'YI10/JH0``8M"``2+I/U"TX1X#:I%0"6+
MP@$$RJU\0))"``9*0T`CBZ('0?FF_5O30@`!BV,``HO&%`VJ9D`FB^/]0M-C
M>`^JSWQ`DH(``\I"``5*I0M!^4)`+HNE``&+0@`%B^7]6].E%`^J14`EBZ+]
M0M-">`VJK7Q`DFX``LK&`09*Q$`DBZ8/0?G&``&+A``&BZ;]6]/&%`VJAD`F
MB^3]0M/.?$"2A'@/JD\`!,KE`05*HT`CBZ430?FE``&+8P`%B\7]6].E%`ZJ
M94`EBZ/]0M-C>`VJK7Q`DH\``\KF`09*PD`BBZ870?G&``&+0@`&BZ;]6]/&
M%`VJ1D`FB\+]0M-">`ZJSGQ`DF\``LKE`05*I$`DBZ4;0?FE``&+A``%B\7]
M6].E%`ZJA4`EBZ3]0M.$>`VJK7Q`DD\`!,KF`09*PT`CBZ8?0?G&``&+8P`&
MBZ;]6]/&%`VJ9D`FB\/]0M-C>`ZJSGQ`DH\``\KE`05*HD`BBZ4C0?FE``&+
M0@`%B\7]6].E%`ZJ14`EBZ+]0M-">`VJK7Q`DF\``LKF`09*Q$`DBZ8G0?G&
M``&+A``&BZ;]6]/&%`VJAD`FB\3]0M.$>`ZJSGQ`DD\`!,KE`05*HT`CBZ4K
M0?FE``&+8P`%B\7]6].E%`ZJ94`EBZ/]0M-C>`VJK7Q`DH\``\KF`09*PD`B
MBZ8O0?G&``&+0@`&BZ;]6]/&%`VJ1D`FB\+]0M/0?$"20G@.JFX``LK%`05*
MI$`DBZ4S0?FE``&+A``%BP7^6].E%!"JA4`EBZ3]0M.O?$"2A'@-JDT`!,JF
M`09*[OU;T\-`(XNF-T'YSA4/JL8``8MC``:+!OY"TVY`+HO&>!"JS7U`DH,`
M!LIE``5*HSM!^:)`(HNE_5O38P`!BT(``XNE%`VJ14`EB^+]0M.C?$"20G@/
MJL\``LKN`0Y*Q$$DBZX_0?G.`0&+A``.BV[\6]/.%0.JD$`NBZ3]0M.->`VJ
M!'Y`DDX`#<K%`05*ID`FBZ5#0?FE``&+Q@`%BX7\6].E%`2JST`EBV7\0M/F
M?4"2HW@#JJ4!`\IL``P+I0`02J)`(HNE1T'YI0`!BT4`!8O"_%O30A0&JD(`
M!0N%_$+3*0$""Z1X!*H)!`#Y8P`$RH0`"PMC``]*!+`!J:1+0?E%_%O38T`M
MBX$``8MC``&+H10"JB$``PLG``<+!P``^:%/0?D"`4#Y(@`"RL'\0M,A>`:J
M*@`*"PH(`/F"``"U_7O!J/]#"I'``U_61?K_E_U[O*G]`P"1\U,!J?5;`JGW
M8P.I@`8`M*(``-!"]$?Y6`!`^1@&`+0"`$`Y%0"`4E_T`'%$&$!Z`0,`5!,#
M0/GS`0"T]P,!JO8#`*JU?D"3]`,8JN`#$ZKB`Q6JX0,6J@3Z_Y>````U8&IU
M.!_T`'%``@!4DXY`^//^_[7@`Q.J\U-!J?5;0JGW8T.I_7O$J,`#7]8?(`/5
M]0,`JJ(>0#A?]`!Q1!A`>J'__U2U`@!+X___%Q\@`]6``AC+M08`D7,"%8L`
M_$.3X`(`N>`#$ZKS4T&I]5M"J?=C0ZG]>\2HP`-?UA,`@-+E__\7'R`#U?U[
MO*G]`P"1]5L"J;8``-#S4P&ILP``T/4#`*JTTP"1P-I'^7/V1_D!`$#YH1\`
M^0$`@-+A`Q2JX`,5JK7__Y?@`0"THS>`N6("0/E`#`.+`01`^4%X(_CA_O^T
M`"``D0$$0/D!``#YH?__M>$#%*K@`Q6JI___EV#^_[76VD?YH1]`^<`"0/D@
M``#*H```M?-30:GU6T*I_7O$J,`#7];@^?^7'R`#U?U[N:G]`P"1\U,!J?,#
M`:KU6P*IM0``T/=C`ZGT`P"J^6L$J?LK`/F@VD?Y(0!`.3_T`'$!`$#YH3<`
M^0$`@-)S%I.:X`,3JECY_Y?W`P"JH9,!D>`#%*J$__^7(`@`M/8#`*I1^?^7
M_P(`Z^D&`%2V9X"YN0``T-;R?=.``D`Y'_0`<0080'H@#`!4X0,4JB`<0#@?
M]`!Q!!A`>J'__U0A`!3+(7Q`DSGW1_G@"@"1```!BS<#0/EX^?^7X&HV^``+
M`+2C9X"Y@`8`D2(#0/F!`D`Y/_0`<4)X8_@D&$!Z00``.<```%0!%$`X/_0`
M<4$<`#@D&$!Z@?__5*`'@%)!!`"10```.6`60#@@%``XP/__-0``@%*UVD?Y
MHC=`^:$"0/E!``'*`0@`M?-30:GU6T*I]V-#J?EK1*G[*T#Y_7O'J,`#7]8`
M`(#286I@.,%J(#@`!`"1H?__->[__Q>Y``#0(/='^18`0/G``D#Y(`4`M.$#
M%JH``(!2`@``%.`#&"HBC$#X&`0`$:+__[4`#``1`'Q]DZ$``/`BB$"YP@$`
M-.$#`*K@`Q:J:_G_ER'W1_D@``#Y0`,`M!M_0)/Z`P"J=O-]TWL'`)%?>SOX
MN&<`N:K__Q<B`(!2(H@`N2[Y_Y?Z`P"JP`$`M!M_0)/A`Q:J=O-]T^(#%JKC
M^/^7(/='^1H``/GP__\7`0"`TJ;__Q<``H#2&`"`4M___Q<``(`2O?__%U3Y
M_Y<?(`/5_7NRJ?T#`)'U6P*IM0``T/-3`:GW8P.I^6L$J:':1_DB`$#YHF\`
M^0(`@-*```"T`0!`.?8#`*J!`0`UM=I'^:%O0/F@`D#Y(```RD`)`+7S4T&I
M]5M"J?=C0ZGY:T2I_7O.J,`#7];@^/^7]P,`JF#^_[08``#0N6,!D1@C$9'4
M!8!2X`,7JG3Y_Y?S`P"JX`$`M&%.0#F!`@%K(0(`5&!20#D`__\T@`(`:^`#
M`$M!``!48%9`.6`!`#7@`Q>J9OG_E_,#`*I@_O^UX`,7JAKY_Y?@`Q:J1/G_
ME]C__Q<A_?\TX`,6JG-.`)&C^/^7^@,`JN`#$ZJ@^/^7```:"P`(`!$`?$"3
MV/C_E_H#`*KE`Q.JY`,6JN,#&*H"`("2(0"`4IGX_Y?B`QFJX0,:J@``@%*=
M^/^7'P0`,:```%2@:T"Y``P4$A\00''@``!4X`,:JG7Y_Y?@`QJJ-_G_E\G_
M_Q<?(`/5X`,:JJ7__Y?Z__\7]?C_E_U[OJG]`P"1\U,!J;,``-#T`P"J<\Y'
M^6`"0+GA^/^7`@`(D>$#%*H``(!2(?G_E\```#0``(!2\U-!J?U[PJC``U_6
M'R`#U6`"0+G5^/^7`!!"N0`,%!(?$$!QX```5&`"0+G/^/^7`!!"N0`,%!(?
M*$!Q`?[_5.`#%*I!`(!2Z/C_EQ\``''@%Y\:\U-!J?U[PJC``U_6_P=`T0(`
M`-#_0P#1_7N\J?T#`)'S4P&IM```T/5;`JFU(P&1]QL`^?8#`*J#VD?Y0$`1
MD?<#`:KA`Q6J9`!`^:0G"/D$`(#2XO^!TE?X_Y<?``!Q#00`5`,$`%&ARF,X
M@0,`-.,#`"IS?$"3X`,5JN(#$ZKA!8!2$/G_E\`"`+2@``#0`,Q'^0``0+F?
M^/^7XP,3JN(#%:KA`Q:J#_G_EY3:1_FA)TCY@`)`^2```,H@`@"U\U-!J?5;
M0JGW&T#Y_7O$J/\'0)'_0P"1P`-?UL/\_S6@``#0`,Q'^0``0+F*^/^7X@,7
MJN$#%JIG^/^7[/__%Y'X_Y>@``#0_7N_J?T#`)$`S$?Y``!`N7_X_Y>B``#0
M`P``T`$``-!C0!"1_7O!J"&`$9%"R$?YM_C_%_U[OJG]`P"1\PL`^;,``-!S
MSD?Y8`)`N7#X_Y?K__^78`)`N6WX_Y?S"T#Y!```T`(``+"$X!Z1`0``T/U[
MPJCC`P2J0L`\D2$`$I$%`(!2OOC_%Q\@`]7_"T#1_X,`T?U[O:G]`P"1\U,!
MJ;0``-#U6P*IL^,`D8#:1_D!`$#YH2<0^0$`@-(D^/^7Y`,`*@4``-`#``#0
MI6`2D6.`$I'@`Q.J(@""TB$`@%+G]_^7``3X-P`(@M("`(+2M@,`B^`#$ZKA
M`Q:J[/?_E_,#`*H``_@W``0`$0!\0),3^/^7]0,`JL```+1S?D"3X0,6JN(#
M$ZK%]_^7OVHS.)3:1_G@`Q6JHB=0^8$"0/E!``'*00$`M?-30:GU6T*I_7O#
MJ/\+0)'_@P"1P`-?UA\@`]45`(#2\O__%S3X_Y<?(`/5QO__%Q\@`]7_!T#1
M`@``T/]#`-']>[JI_0,`D?=C`ZFW``#0\U,!J?0#`*KU6P*I0.`2D?EK!*GS
M`P&J^RL`^:&3`9'BVD?Y0P!`^:,W"/D#`(#2V?W_E_4#`*K@`Q2JX06`4FWX
M_Y>``@"T````T.$#%*H`(!.1-O[_E^`#%*KWVD?YHC=(^>$"0/E!``'*P0P`
MM?-30:GU6T*I]V-#J?EK1*G[*T#Y_7O&J/\'0)'_0P"1P`-?UN`#%*H6``#0
MUF(3D8WW_Y?Z`P`JX0,6JN`#$ZJ%]_^7\P,`JH#\_[1@`D`Y&0``T!@``-`Y
M@Q.1&*,3D<`&`#2U``"TX0,3JN`#%:H1^/^70`4`-.`#$ZIZ]_^7X0,`*F#"
M((L`\%\X'[P`<>$``%0A!`!18,(ABW_*(3@`\%\X'[P`<6#__U1`!P`1`0`!
M"S_\/W$,^?]4NZ,!D>0#$ZKF`Q2JY0,9JN,#&*K@`QNJLP``T`(`@M(A`(!2
M9??_EW/.1_E@`D"YQO?_EP(`")'A`QNJ``"`4F;W_Y?@```U8`)`N;_W_Y<`
M$$*Y``P4$A\@0'&``@!4X0,6J@``@-),]_^7\P,`JF#U_[1@`D`Y@/G_-1,`
M`+`5`0"T<\(2D>`#%:KA`Q.JVO?_ER$`@%)`_O\TU?__%R$`@%)SPA*1TO__
M%^`#&ZHA`(!2Q??_ET#]_S4```"PX0,;J@`@$Y'._?^7X`,;JE[W_Y>7__\7
MJ/?_EQ\@`]4!`$`YP0``-`($`)$_O`!Q`!""FD$40#BA__\UP`-?UOU[OJG]
M`P"1\U,!J6`#`+04`$`Y\P,`JA0#`#0C]_^7``0`T6("`(M_`@+K8@0`5&!J
M8#@?O`!QH```5!P``!1``$`Y'[P`<2$#`%1"!`#1?P("ZV'__U2?O@!QX```
M5/-30:D```"P_7O"J`"`$Y$V]_\7'R`#U4``@-)']_^70`4`M`(``+!"P!*1
M0@!`>0(``'GS4T&I_7O"J,`#7]9``$`Y'[P`<8`!`%1"!`#1?P("ZV/__U1_
M`@+KX/S_5$($`-%_`@+KX@``5$``0#D?O`!Q@0``5$($`-%_`@+K8___5$(`
M$\M`"`"1'P1`\<@!`%2@``#0X0,3J@`@`I%"!`"1$R``D0,`@M+@`Q.J)O?_
ME^`#$ZKS4T&I_7O"J,`#7]8?(`/5``"`TO-30:G]>\*HP`-?UOU[N*D!``"P
M(4`0D0```+#]`P"1\U,!J;,``+#U6P*I`,`3D?=C`ZD6``"P8]I'^1<``+`F
M'$&I8@!`^:(_`/D"`(#2)!1"J:8?!:DA8$!Y&```L*07!JD4``"PH>,`>91"
M%9&U,P&1+OW_EP```+```!21*_W_EP```+``(!21*/W_EP```+``8!21)?W_
ME\""%)$C_?^7````L`#`%)$@_?^7X.(2D1[]_Y<``Q61'/W_E^`#%*H:_?^7
M````L`"`%9$7_?^7````L``@$Y$4_?^7````L.$#%:H`P!61U/S_EX```+3A
M`P"JX`,4JC;]_Y<```"PX0,5J@`@%I',_/^7H```M`(``+#A`P"J0(`6D2W]
M_Y<```"PX0,5J@#`%I'#_/^70`(`M.$#`*K@XA*1)?W_EP$``+#`@A21(:`7
MD2']_Y=SVD?YH3]`^6`"0/D@``#*8`,`M?-30:GU6T*I]V-#J?U[R*C``U_6
M````L.$#%:H``!>1K?S_E\```+3A`P"J``,5D0_]_Y?J__\7'R`#U0$``+"@
MAP&1(6`7D4(!@-*T0P&1O?;_ET#\_S6!;@"1``,5D0/]_Y?>__\7W_;_E_U[
MO:G]`P"1\U,!J;,``+"T``#08=I'^8`20+DB`$#YHA<`^0(`@-(?!``Q(`$`
M5'/:1_FB%T#Y80)`^4$``<JA`@"U\U-!J?U[PZC``U_6````L*&3`)$``!61
M@_S_ET`!`+0!`$`Y/\``<>`'GQH_``!QX0>?&@```0J`$@"Y[/__%Q\@`]4`
M`(!2@!(`N>C__Q>Y]O^7_7N_J?T#`)%:]O^7V?;_EX```+0``$#Y_7O!J,`#
M7]8``(#2_?__%_U[NZG]`P"1\U,!J;,``+#U6P*I%0``L/<;`/FWPA>18MI'
M^?8#`*JA$P&1X`,7JD,`0/FC)P#Y`P"`TEO\_Y=``@"T`0!`.?0#`*KA`0`T
MX0,6J@GW_Y<``@"T<]I'^:$G0/E@`D#Y(```RB`$`+7S4T&I]5M"J?<;0/G]
M>\6HP`-?UA\@`]7A`Q:JH,(7D:S\_Y?R__\7X`,6JA/V_Y?U`P"JX`,4JA#V
M_Y>@`@"+``@`D4GV_Y?U`P"J!0``L`,``+#F`Q2JI6`3D>0#%JICH!.1`@"`
MDB$`@%(']O^7X0,5JN`#%ZJ6_/^7W/__%W+V_Y<?(`/5_R-`T:(``-#_@P71
M0D``D0,WD-)$(`"1_7NZJ?T#`)'W8P.IN```L/-3`:FA`P.+]5L"J?8#`*KY
M:P2IN4,"D?MS!:FSHP*1`-M'^;4S`I%&'$*I!0!`^24``/D%`(#210Q`^1H`
M`+"T`P.1_T,`T24+`/GA`Q6JA!1`J4#C$I$D%P"I1#!`^88>`*ED"@#Y1!1%
MJ606`*E$%$.I0@Q$J806`:F"#@*I`OS_EX```+0!`$`Y]P,`JL$A`#6)__^7
M%P"`TOP#`*H`#P"TX`,<JLCU_Y<`^'_3``0`D0'V_Y?W`P"JA`-`.80!`#0;
M``"P\P,7JGLC&)'@`Q.JXP,;J@(`@)(A`(!2<PH`D;WU_Y>$'T`X)/__-:!C
M0/D@`@"TE"(`D0,``!2`AD#XH`$`M.$#%:K?^_^7\P,`JF#__[0!`$`Y(?__
M-"K]_Y?@_O\TX`,3JL_U_Y?S`P"JH`$`M10`@%(SVW3X,P$`M&`"0#G@```T
MX`,3JA[]_Y>@"@`UE`8`$3/;=/@S__^U$P"`TN`#$ZJ7]?^7^P,`JN`#%ZJ4
M]?^7&P`;"WL3$!%[?T"3X`,;JLOU_Y?T`P"J`0``L`8``+`#``"P)8`3D><#
M%ZK&0!B1Y`,3JF-@&)$"`("2(0"`4H?U_Y?@`Q2J`3B`4G#V_Y<?!``Q@`<`
M5+,``+!SSD?Y8`)`N>+U_Y<"``B1X0,4J@``@%(B]O^7]P,`*D`(`#2@``"P
M`@``L,,"0/GD`Q2J0N`:D2$`@%(`Q$?Y$P"`T@``0/GZ]?^7&-M'^0$WD-*A
M`P&+X`,3JB(`0/D!`T#Y00`!RH$Y`+6_`P"1\U-!J?5;0JGW8T.I^6M$J?MS
M1:G]>\:H_R-`D?^#!9'``U_6'R`#U7[U_Y?\`P"J8/'_M?<B`)'@:G/XP!(`
MM.$#%:I_^_^78/__M`$`0#G!_O\U]R(`D?C__Q<?(`/5X`,3JI0&`!%N]?^7
M\P,`JB#T_[2K__\7*O;_EP4`0+F_1`!Q0/C_5*```+`"``"PPP)`^>0#%*I"
MH!B1(0"`4@#$1_D3`(#2``!`^<7U_Y?+__\7'R`#U6`"0+F9]?^7`!!"N0`,
M%!(?$$!Q0??_5&`"0+F3]?^7'!A"N4'U_Y>?`P!K@?;_5&`"0+F-]?^7`!!"
MN0`@`!(?``=QP?7_5.`#&ZI;]?^7\P,`J@```+#A`Q6J`,`:D4K[_Y>@#`"T
MU0)`^3_U_Y?A`P"JX`,5JEC]_Y?U`P"JP`L`M.`#%:H0]?^7'PP`<?L#`*KM
M`0!4`'Q`DP$``+``$`#1(:`9D:`"`(N;]?^7``$`-7\3`'$`)@!48!,`4:#"
M((L`\%\X'[P`<6`E`%24_O^7P```->`#%:H!`(!2TO7_EZ!_`+G`"``U`0``
ML````+`AH!>1```5D0(``+`5``"P68`3D;5B&I&%^_^7]@,9JB7U_Y?F`P`J
M!P``L`,``+#GX!Z18R`:D>4#&:KD`Q2JX`,3J@(`@)(A`(!2^P,'JN7T_Y<2
M```4'R`#U<;U_Y<``$"Y'T0`<4$"`%02]?^7]P8`$>8#`"KG`Q<JY0,6JN0#
M%*KC`Q6JX`,3J@(`@)(A`(!2^P,`^=/T_Y?@`Q.J`3B`4KSU_Y<?!``Q@/W_
M5.`#%*IX]?^7X0,3JD#C$I%;^_^7X`,3JHG^_Y=9__\7'R`#U8;^_Y?@`Q>J
MYO3_E_,#`*I3__\7H`&`TAP``+"<`QB1]/3_E_<#`*ID"H!2]/[_%]4"0/FB
M__\70@"`4B$"@)*[XP:1#_7_EZ!_0+GA`QNJP@"`TGOU_Y>@XT8Y@```-:#G
M1CD?#`%QP!T`5*!_0+D"`(!2`0"`TK?#`Y&\HP21`/7_E[__$:DA8(32('&5
MTJ'HK/*@^;WRPI^;TK]K`;FA`P^IP8Z*T@`^G-)!!J+R0'JX\D(7L_*A@Q"I
MX.(`D:*#`/F@.P#YH']`N>$#&ZH"`)#26_7_EQ\``''C`P"J]@,`*LT(`%2B
MCT#Y8'Q`DT$,``M?``'KHI-`^4D``%1"!`"10'1`BZ&#$:F@:T&YP!0`-`$(
M@%*C-P#Y-@``2Z$[0/E_`!9K=M"6&B#`((OA`QNJV7Y`D^(#&:IE]/^7H&M!
MN:,W0/G``@`+'P`!<:!K`;FA^_]4X`,7JG8`%DMY`QF+/_;_E]_^`''-`@!4
MU@(!4<!^!E,59'K3M0(!D:!K`+DU`Q6+)A]`J>`#%ZHD%T&IAA\`J2(/0JF$
M%P&I*"=#J8(/`JF()P.I.0,!D2SV_Y>_`AGK@?[_5*!K0+G6&@!+H#M`^<)^
M0)/A`QFJ`PF`TG_T_Y>V:P&YH']`N>$#&ZH"`)#2%O7_EQ\``''C`P"J]@,`
M*HSW_U2@?T"YN/3_E[;74:GA#X`2P")#TX'+(#@`!``1'^``<6P.`%0"!X!2
MX>(`D4(``$L@P""+`0"`4D)\0).&]/^7H?Y0TZ+^6-/@`Q>JM8\%.:&'!3G!
M_EC3M?Y(TZ*#!3FADP4YPOY0T\'^2-.UBP4YHI<%.;PC!I&VGP4Y&P``L*&;
M!3GX]?^7I0]/J?4#'*JESP4YML<%D:('4*FD?!A3IOQ0TZ7\2-.CWP4YEZ,`
MD:7+!3EE_%C3HN\%.7LC&)&ETP4Y9?Q0TV/\2-.@BT#YH?\%.:/;!3E#_%C3
MH`\&.:/C!3E#_%#30OQ(TZ3#!3FFQP4YHNL%.2+\6-.EUP4YHO,%.2+\4-,A
M_$C3H^<%.:+W!3D"_%C3H?L%.0'\4-,`_$C3H@,&.:$'!CF@"P8Y`@``%,06
M0#C@`Q6JXP,;J@(`@)(A`(!2M0H`D?+S_Y?_`A7K`?__5````+`'``"P`P``
ML`6`$Y'GX!Z1Y@,<JN0#%*ICX!F1X`,3J@(`@)(A`(!2O\,&.>/S_Y?@`Q2J
MC?3_E^$#$ZI`XQ*1</K_E^`#$ZJ>_?^7;O[_%_D#&ZIO__\7U@9`^;;:_[3@
M`Q:JT?/_EQ\,`/$IVO]4`!``T0$``+`AP!F1P`(`BU[T_Y<?``!QM1*6FLG^
M_Q<""(!2^^(`D4(``$L!`(!28,,@BT)\0),4]/^7X`,7JI;U_Y=_?P"I?W\!
MJ7]_`JG_-@#YB/__%Z#K1CD?!`%Q(>+_5*#O1CD?#`%QP>'_5*#S1CD?(`%Q
M8>'_5*#W1CD?%`%Q`>'_5+5_0+E"`(!2(0>`DN`#%2H(]/^7X0,;JN`#%2HB
M!8#2=/3_EP```+`'``"P`P``L`6`$Y'GX!Z1Y@,;JN0#%*ICX!F1X`,3J@(`
M@)(A`(!2G//_E\[^_Q<*]/^7'R`#U?U[N*G]`P"1]V,#J;@``+"@TP&1]5L"
MJ:`W`/GU`P"JH```L/-3`:D3ST?Y^6L$J?MS!:D`V$?Y`0!`^:$_`/D!`(#2
M8`)`N>KS_Y?T`P"J8`)`N>?S_Y<"X$(Y`P``L.$#%:I@@!21@N8".:GY_Y>`
M``"T`0!`.3_$`''@$@!4F/S_EQ;/1_F[``#PP`)`N=CS_Y<!``"P8P&`4B%`
M')$B`(!2Y_/_EV`&`+1U(P:1`0A`^:""4+@W%$#Y'P0`<:T%`%09@(!2%`"`
M4C,`@%(9!*!R"@``%$$(0/G@`QJJ\//_E^`#`#6@@E"X<P8`$90&`!$?`!-K
MC0,`5,`"0+F\\_^7@GY`D^$#%ZH#`(!2'/3_E_P#`*I``@"T`@!`^:,"4?A`
M#$"Y>MAS^```&0H?`!!Q(/W_5,`"0+FM\_^7@0-`^4,`@%("`(#2F?/_E^$#
M`*K@`QJJTO/_EV#\_S1@(P:1`(!0N`$$`%$_`!1KP`L`5!3/1_F``D"YG?/_
MEP$``)!C`(!2(6`<D2(`@%*L\_^7\P,`JH`!`+2``D"YE//_EV$*0/D"``"0
M0H`<D2$`0/EO\_^78`I`^0``0/D`#$"YX`RP-Q3/1_F``D"YB//_EP$``)!C
M`(!2(:`<D2(`@%*7\_^7\P,`JJ`!`+0```"0H3=`^0`@$Y%%^?^7]0,`JH`"
M0+G5"0"T>?/_EV$*0/GB`Q6J(0!`^57S_Y<8ST?Y=",&D0`#0+EQ\_^7\P,`
MJ@`#0+EN\_^7`0``D"(`@%(AP!R1HO/_E^$#`*H"``"0X`,3JD(@'9%%\_^7
M``-`N6/S_Y<?Y`(Y`@``D*$W0/E`X!*1)OG_EX""$?CS`P"JX`0`M.`#$ZH!
M.(!2X//_EP$$`!$_!`!Q!(A1>N$&`%2@``"0&MA'^:$_0/E``T#Y(```R@`&
M`+7S4T&I]5M"J?=C0ZGY:T2I^W-%J?U[R*C``U_6``1`.4#M_S1H__\7'R`#
MU1\$`'%-]/]4%<]'^70C!I$S`(!2H`)`N7,&`!$[\_^7X0,7JO'R_Y>`@E"X
M'P`3:RS__U26__\7@`)1^,_\_Y>`@A'X\P,`JL#Z_[4```"0`$`=D6GS_Y<L
M\_^78",&D6(*0/D!`%'X0`!`^2$`0/ED^O^7L?__%X`"0+DC\_^780I`^2$`
M0/ET\_^7E?__%RKS_Y=[(P:1`0``D.,#`"H@X!V1X@,3JF$#4?@A`$#Y4O/_
MEQ\@`]7]>[ZI_0,`D?-3`:GT`P"J?OO_EP$`0#G!`@`T`@0`D?,#`*H_O`!Q
M<Q*"FD$40#BA__\U-?S_EY\"`/$$&$!Z(`$`5(`"0#G@```T`0``D.`#$ZHA
M0!B1>O/_EW\"`.O```!4\U-!J?U[PJC``U_6\P,`JO#__Q?@`Q2J\U-!J?U[
MPJBM^?\7HP``D&/<1_F#``"T8P!`^:KR_Q<?(`/5`P"`TJ?R_Q?]>[RI_0,`
MD?5;`JFU``"0\U,!J;0``)"UHBN1E,(KD90"%<OW8P.I]@,"JO@#`"KW`P&J
M6?+_EY3^0Y-4`0"T$P"`TJ-Z<_CB`Q:JX0,7JN`#&"IS!@"18``_UI\"$^LA
M__]4\U-!J?5;0JGW8T.I_7O$J,`#7];``U_6_7N_J?T#`)']>\&HP`-?U@``
M```!``(``````'!E<FQX<VDN8P````````!?7T5.5E]005)?0TQ%04Y?7R`@
M("`@("`@("`@("`@(```````````)7,O)7,````O<')O8R]S96QF+V5X90``
M1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R``````!);G1E<FYA;',Z.E!!
M4CHZ0D]/5`````!E>&4``````"]P<F]C+R5I+R5S```````N`````````%!!
M4E]414U0``````````!005)?4%)/1TY!344`````.@`````````O````````
M`"5S)7,E<P``4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0`````
M`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!0
M05)?0TQ%04X`````````4$%27T1%0E5'`````````%!!4E]#04-(10``````
M``!005)?1TQ/0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@``
M``````!005)?5$U01$E2````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"
M04Q?0TQ%04X``````````%!!4E]#3$5!3CT````````Q`````````$Q$7TQ)
M0E)!4EE?4$%42`!365-414T``"4P,G@`````<&%R+0`````E<R5S)7,E<P``
M````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@```````'!A<FP`````+G!A<@`````E<R5S
M8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`
M`````````%!!5$@`````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES
M('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R
M871I;VXI"@```````$%21U8`````&`````````!P97)L`````#``````````
M4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP,S<```!5;F%B;&4@=&\@8W)E
M871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N(&]F('!R
M:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI
M"@``````````)7,````````M90```````"TM````````55-%4@````!54T52
M3D%-10``````````5$U01$E2``!414U01$E2`%1%35``````5$U0```````O
M=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D
M0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C
M:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I
M;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R
M7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@
M/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E
M;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM
M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A8
M6"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*
M4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@
M(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M
M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N
M"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B
M("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I
M;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU
M;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q
M*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA
M;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.
M5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H
M)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@
M*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G
M*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG
M(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D[
M"FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@
M;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P
M<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL
M92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS
M965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N
M("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F
M+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z
M("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H
M)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F
M9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E
M="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D
M:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL
M(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I
M("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B
M*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP
M86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U
M;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*
M;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ
M*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X
M="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I
M9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.
M5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A
M<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N
M86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*
M)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*
M<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H
M)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O
M<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI
M<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R
M97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K
M97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I
M9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]
M("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,
M14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I
M.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I
M.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M/GMB=69]*3L*
M;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A
M9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]
M"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U
M;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR
M97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@
M:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N
M86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M
M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@
M>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O
M;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M
M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R
M=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D
M;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%
M3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A
M('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%2
M7T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP
M87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP
M("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?
M<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@
M86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.
M5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO
M<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!
M4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO
M(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L
M<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L
M<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G
M8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2![
M"B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE
M="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^
M(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L
M<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`
M05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@
M)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I
M<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)0
M05(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS
M:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q
M=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A
M<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@
M>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@
M;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z
M("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*
M;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D
M;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-
M151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]
M?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG
M.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E
M;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A0
M05(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2
M/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F
M:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@
M?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL
M"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN
M960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L
M(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K
M97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG
M(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?
M7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L
M;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@
M>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R
M:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U
M:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G
M<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@
M;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E
M9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E
M9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG
M.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T
M(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY
M("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D
M9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q
M+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#
M8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A
M8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0[
M"GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B
M)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R
M968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T
M<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M
M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@
M*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS
M92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@
M)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X[
M"F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L
M>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N
M9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA
M;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I
M;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE
M*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI
M=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F
M:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP
M<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D
M9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE
M+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM
M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].
M('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V
M97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@
M:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L
M("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I
M.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^
M:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H
M-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#
M2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I
M;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U
M=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H
M7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II
M<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@
M(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M
M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R
M+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL
M94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL
M:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG
M.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A
M8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T
M9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D
M9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ
M92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@
M:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92![
M"F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?
M;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA
M;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R
M97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@
M<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV
M93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ
M3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER
M92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*
M<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]
M("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD
M7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI
M+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN
M960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N
M86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI
M(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.
M86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS
M:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE
M;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52
M?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S
M=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(
M*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%
M3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE
M*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@
M)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U
M9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D
M9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T
M>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^
M;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E
M<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U
M.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@
M>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S
M:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C
M='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E
M('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2![
M"F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I
M.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H
M("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D
M9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@
M/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A
M<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D
M8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T
M96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N
M86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP
M;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM
M;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO
M9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D
M=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*
M<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD
M969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!
M345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@
M?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M
M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R
M*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II
M9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N
M/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@
M*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![
M"FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%
M3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O
M+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P
M<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-
M17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P
M*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T
M8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E
M=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O
M7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E
M;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@
M7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@
M/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%
M1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#
M04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG
M4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'
M("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R
M7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*
M:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM
M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,
M14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY0
M05)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U
M:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS
M92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@
M0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z
M.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R
M8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI
M.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@
M<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B
M.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O
M9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?
M7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?
M15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/
M4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"H)````````&`D```````````````````!``````````$`
M`````````0````````#?`0````````$`````````Z@$````````!````````
M`/0!`````````0````````!#`@````````$`````````G@,````````!````
M`````,8#````````#``````````0'0````````T`````````]%,````````9
M`````````.B:`0``````&P`````````(`````````!H`````````\)H!````
M```<``````````@`````````]?[_;P````!@`@````````4`````````N`T`
M```````&`````````%`#````````"@`````````K!0````````L`````````
M&``````````5`````````````````````P````````!0G0$```````(`````
M``````8````````4``````````<`````````%P`````````0%P````````<`
M````````*!0````````(`````````.@"````````"0`````````8````````
M`!X`````````"`````````#[__]O``````$```@`````_O__;P````#($P``
M`````/___V\``````P````````#P__]O`````.02````````^?__;P`````1
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````,!T````````P'0```````#`=````````
M,!T````````P'0```````#`=````````,!T````````P'0```````#`=````
M````,!T````````P'0```````#`=````````,!T````````P'0```````#`=
M````````,!T````````P'0```````#`=````````,!T````````P'0``````
M`#`=````````,!T````````P'0```````#`=````````,!T````````P'0``
M`````#`=````````,!T````````P'0```````#`=````````,!T````````P
M'0```````#`=````````,!T````````P'0```````#`=````````,!T`````
M```P'0```````#`=````````,!T````````P'0```````#`=````````,!T`
M```````P'0```````#`=````````,!T````````P'0```````#`=````````
M,!T````````P'0```````#`=````````,!T````````P'0```````#`=````
M````,!T````````P'0```````#`=````````,!T````````P'0```````#`=
M````````,!T````````P'0```````#`=````````,!T`````````FP$`````
M`/!3````````````````````````````````````````````````````````
M``````````````````````````````````````B@`0````````````````!X
M4P``````````````````4"$`````````````````````````````````````
M````````````````````````"*`!``````#_____`````!!8````````L%0`
M`````````````````*!5````````\%<```````#X5P````````!8````````
M"%@``````````````````-A7````````X%<``````````````````!A8````
M````1T-#.B`H1&5B:6%N(#8N-"XP+3(I(#8N-"XP(#(P,3<P-S(T```N<VAS
M=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI
M9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU
M+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF
M:6YI`"YR;V1A=&$`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y
M`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````````
M````````````````````````````````````````````````````````````
M``````````````````````L````!`````@```````````@`````````"````
M````&P````````````````````$````````````````````3````!P````(`
M````````'`(````````<`@```````"`````````````````````$````````
M````````````(0````<````"`````````#P"````````/`(````````D````
M````````````````!````````````````````#0```#V__]O`@````````!@
M`@```````&`"````````[``````````%``````````@`````````````````
M```^````"P````(`````````4`,```````!0`P```````&@*````````!@``
M``,````(`````````!@`````````1@````,````"`````````+@-````````
MN`T````````K!0```````````````````0```````````````````$X```#_
M__]O`@````````#D$@```````.02````````W@`````````%``````````(`
M`````````@````````!;````_O__;P(`````````R!,```````#($P``````
M`&``````````!@````,````(````````````````````:@````0````"````
M`````"@4````````*!0```````#H`@````````4`````````"``````````8
M`````````'0````$````0@`````````0%P```````!`7``````````8`````
M```%````%0````@`````````&`````````!^`````0````8`````````$!T`
M```````0'0```````!0````````````````````$````````````````````
M>0````$````&`````````#`=````````,!T````````@!```````````````
M````$``````````0`````````(0````!````!@````````!0(0```````%`A
M````````I#(```````````````````@```````````````````"*`````0``
M``8`````````]%,```````#T4P```````!`````````````````````$````
M````````````````D`````$````"``````````A4````````"%0```````!(
M0```````````````````"````````````````````)@````!`````@``````
M``!0E````````%"4````````!`````````````````````0`````````````
M``````"B````#@````,`````````Z)H!``````#HF@````````@`````````
M```````````(``````````@`````````K@````\````#`````````/":`0``
M````\)H````````(````````````````````"``````````(`````````+H`
M```!`````P````````#XF@$``````/B:````````"```````````````````
M``@```````````````````"_````!@````,``````````)L!````````FP``
M`````%`"````````!@`````````(`````````!``````````R`````$````#
M`````````%"=`0``````4)T```````"P`@``````````````````"```````
M```(`````````,T````!`````P``````````H`$```````"@````````@```
M``````````````````@```````````````````#3````"`````,`````````
M@*`!``````"`H````````#`0```````````````````(````````````````
M````V`````$````P````````````````````@*`````````E````````````
M`````````0`````````!``````````$````#````````````````````````
I`*6@````````X0````````````````````$`````````````````````
